@@ -4,7 +4,7 @@
     created              : Sun Jan 30 12:00:15 CET 2000
     copyright            : (C) 2000 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: car.h 4560 2012-03-04 18:33:41Z pouillot $
+    version              : $Id: car.h 5674 2013-08-10 21:42:15Z torcs-ng $
 
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 /** @file
     		This is the car structure.
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: car.h 4560 2012-03-04 18:33:41Z pouillot $
+    @version	$Id: car.h 5674 2013-08-10 21:42:15Z torcs-ng $
     @ingroup	carstruct
     @note	Short cuts are to be used with the carElt structure.
 */
@@ -73,6 +73,8 @@ typedef struct {
 /** Static Public info */
 typedef struct {
     char	name[MAX_NAME_LEN];	/**< Driver's name */
+    char	sname[MAX_NAME_LEN];	/**< Driver's short name */
+    char	codename[3+1];	/**< Driver's 3-letter codename */
 	char	teamname[MAX_NAME_LEN];	/**< Team name */
     char	carName[MAX_NAME_LEN];	/**< Car object name */
     char	category[MAX_NAME_LEN];	/**< Car's category */
@@ -111,6 +113,8 @@ typedef struct {
 
 /* structure access shortcuts */
 #define _name		info.name			/**< short cut to tInitCar#name */
+#define _sname		info.sname			/**< short cut to tInitCar#sname */
+#define _cname		info.codename		/**< short cut to tInitCar#codename */
 #define _teamname	info.teamname		/**< short cut to tInitCar#teamname */
 #define _carName	info.carName			/**< short cut to tInitCar#carName */
 #define _category	info.category			/**< short cut to tInitCar#category */
@@ -292,17 +296,20 @@ typedef struct {
     tdble rollRes;              /**< rolling resistance, useful for sound */
 	tdble   temp_in, temp_mid, temp_out;
 	tdble   condition;
+	tdble slipNorm; /* normalized slip, the variable of Magic Formula */
 	tdble slipSide;
 	tdble slipAccel;
 	tdble Fx;
 	tdble Fy;
 	tdble Fz;
+	tdble effectiveMu;
 } tWheelState;
 /* structure access */
 #define _ride(i)	priv.wheel[i].relPos.z
 #define _brakeTemp(i)	priv.wheel[i].brakeTemp
 #define _wheelSpinVel(i) priv.wheel[i].spinVel
 #define _wheelSeg(i)	priv.wheel[i].seg
+#define _wheelSlipNorm(i) priv.wheel[i].slipNorm
 #define _wheelSlipSide(i) priv.wheel[i].slipSide
 #define _wheelSlipAccel(i) priv.wheel[i].slipAccel
 #define _wheelFx(i) priv.wheel[i].Fx
@@ -312,6 +319,7 @@ typedef struct {
 #define _tyreT_mid(i) priv.wheel[i].temp_mid
 #define _tyreT_out(i) priv.wheel[i].temp_out
 #define _tyreCondition(i) priv.wheel[i].condition
+#define _tyreEffMu(i) priv.wheel[i].effectiveMu
 
 #define MAX_GEARS	10	/* including reverse and neutral */
 
@@ -370,6 +378,7 @@ typedef struct {
 	tCollisionState collision_state; /**< collision state ; Simu V3 only  */
     tMemPoolCar	memoryPool;
     tdble       driveSkill;           /**< Skill level for robots: 0.0 means as fast as possible; 10.0 means at a slower speed so players can easier win */
+    tdble       steerTq;        /**< torqu on steering wheel for force feedback */
 } tPrivCar;
 /* structure access */
 #define _fuelTotal priv.fuel_consumption_total
@@ -400,6 +409,7 @@ typedef struct {
 #define _smoke		priv.smoke
 #define _normal		priv.normal
 #define _coll2Pos	priv.collpos
+#define _steerTq	priv.steerTq
 
 #define _newTrackMemPool	priv.memoryPool.newTrack
 #define _newRaceMemPool		priv.memoryPool.newRace
@@ -407,35 +417,71 @@ typedef struct {
 #define _shutdownMemPool	priv.memoryPool.shutdown
 
 /** Info returned by driver during the race */
+/** New order to get better alignment, additional parameters for new features */
 typedef struct {
-    tdble	steer;	    /**< Steer command [-1.0, 1.0]  */
-    tdble	accelCmd;   /**< Accelerator command [0.0, 1.0] */
-    tdble	brakeCmd;   /**< Brake command [0.0, 1.0] */
-    tdble	clutchCmd;  /**< Clutch command [0.0, 1.0] */
-    int		gear;  	    /**< [-1,6] for gear selection */
-    int		raceCmd;    /**< command issued by the driver */
-#define RM_CMD_NONE		0	/**< No race command */
+    tdble	steer;	            /**< Steer command       [-1.0, 1.0]  */
+    tdble	accelCmd;           /**< Accelerator command [ 0.0, 1.0] */
+    tdble	brakeCmd;           /**< Brake command       [ 0.0, 1.0] */
+    tdble	clutchCmd;          /**< Clutch command      [ 0.0, 1.0] */
+
+	// New commands for single wheel braking
+	tdble	brakeFrontLeftCmd;  /**< Brake front left command  [0.0, 1.0] 0: no brake; 1: max brake */
+    tdble	brakeFrontRightCmd; /**< Brake front right command [0.0, 1.0] 0: no brake; 1: max brake */
+    tdble	brakeRearLeftCmd;   /**< Brake rear left command   [0.0, 1.0] 0: no brake; 1: max brake */
+    tdble	brakeRearRightCmd;  /**< Brake rear right command  [0.0, 1.0] 0: no brake; 1: max brake */
+
+	// New commands for variable wings (incl. airbrake)
+    tdble	wingFrontCmd;       /**< Wing angle of attack front [0, PI/4: angle in rad] */
+    tdble	wingRearCmd;        /**< Wing angle of attack rear  [0, PI/4: angle in rad] */
+    tdble	reserved1;          /**< reserved for future use */
+    tdble	reserved2;          /**< reserved for future use */
+
+	int		gear;  	            /**< [-1,MAX_GEARS - 2] for gear selection */
+    int		raceCmd;            /**< command issued by the driver */
+#define RM_CMD_NONE		0	    /**< No race command */
 #define RM_CMD_PIT_ASKED	1	/**< Race command: Pit asked */
 #define RM_CMD_MAX_MSG_SIZE 32
-    char	msg[4][RM_CMD_MAX_MSG_SIZE];     /**< 4 lines of 31 characters : 0-1 from car, 2-3 from race engine */
-#define RM_MSG_LEN	31
-    float	msgColor[4]; /**< RGBA of text */
-    int		lightCmd;    /**< Lights command */
+
+	int		lightCmd;           /**< Lights command */
 #define RM_LIGHT_HEAD1		0x00000001	/**< head light 1 */
 #define RM_LIGHT_HEAD2		0x00000002	/**< head light 2 */
-    int		ebrakeCmd;   /**< Parking/Emergency Brake command */
+
+	int		ebrakeCmd;          /**< Parking/Emergency Brake command */
+
+	int	    wingControlMode;        /**< 0: No wing control; 1 fixed wing angles; 2 variable wing angles */
+	int	    singleWheelBrakeMode;   /**< 0: No single wheel brake; 1 single wheel brake mode */
+	int	    switch3;                /**< reserved for future use */
+	int	    telemetryMode;          /**< Define mode for telemetry output: 0: no output; 1: full output; ... see car.cpp SimCarUpdate2 */
+
+	char	msg[4][RM_CMD_MAX_MSG_SIZE];     /**< 4 lines of 31 characters : 0-1 from car, 2-3 from race engine */
+#define RM_MSG_LEN	31
+
+	float	msgColor[4]; /**< RGBA of text */
 } tCarCtrl;
 #define _steerCmd	ctrl.steer
 #define _accelCmd	ctrl.accelCmd
 #define _brakeCmd	ctrl.brakeCmd
 #define _clutchCmd	ctrl.clutchCmd
+
 #define _gearCmd	ctrl.gear
 #define _raceCmd	ctrl.raceCmd
-#define _msgCmd		ctrl.msg
-#define _msgColorCmd	ctrl.msgColor
 #define _lightCmd	ctrl.lightCmd
 #define _ebrakeCmd	ctrl.ebrakeCmd
 
+#define _brakeFLCmd	ctrl.brakeFrontLeftCmd
+#define _brakeFRCmd	ctrl.brakeFrontRightCmd
+#define _brakeRLCmd	ctrl.brakeRearLeftCmd
+#define _brakeRRCmd	ctrl.brakeRearRightCmd
+
+#define _wingFCmd	ctrl.wingFrontCmd
+#define _wingRCmd	ctrl.wingRearCmd
+
+#define _msgCmd		ctrl.msg
+#define _msgColorCmd	ctrl.msgColor
+
+#define _telemetryMode ctrl.telemetryMode
+#define _singleWheelBrakeMode ctrl.singleWheelBrakeMode
+
 struct RobotItf;
 
 /** Command issued by the car during pit stop */
@@ -471,87 +517,99 @@ typedef struct CarElt
 
 /* Sections in XML description files */
 
-#define SECT_SIMU_SETTINGS "Simulation Options"
-#define SECT_CAR		"Car"
-#define SECT_FRNT		"Front"
-#define SECT_FRNTWING		"Front Wing"
-#define SECT_FRNTAXLE		"Front Axle"
-#define SECT_FRNTARB		"Front Anti-Roll Bar"
-#define SECT_FRNTRGTWHEEL	"Front Right Wheel"
-#define SECT_FRNTLFTWHEEL	"Front Left Wheel"
-#define SECT_FRNTRGTSUSP	"Front Right Suspension"
-#define SECT_FRNTLFTSUSP	"Front Left Suspension"
-#define SECT_FRNTRGTBRAKE	"Front Right Brake"
-#define SECT_FRNTLFTBRAKE	"Front Left Brake"
-#define SECT_FRNTDIFFERENTIAL	"Front Differential"
-#define SECT_REAR		"Rear"
-#define SECT_REARWING		"Rear Wing"
-#define SECT_REARAXLE		"Rear Axle"
-#define SECT_REARARB		"Rear Anti-Roll Bar"
-#define SECT_REARRGTWHEEL	"Rear Right Wheel"
-#define SECT_REARLFTWHEEL	"Rear Left Wheel"
-#define SECT_REARRGTSUSP	"Rear Right Suspension"
-#define SECT_REARLFTSUSP	"Rear Left Suspension"
-#define SECT_REARRGTBRAKE	"Rear Right Brake"
-#define SECT_REARLFTBRAKE	"Rear Left Brake"
-#define SECT_REARDIFFERENTIAL	"Rear Differential"
+#define SECT_SIMU_SETTINGS			"Simulation Options"
+#define SECT_CAR					"Car"
+#define SECT_FRNT					"Front"
+#define SECT_FRNTWING				"Front Wing"
+#define SECT_FRNTAXLE				"Front Axle"
+#define SECT_FRNTARB				"Front Anti-Roll Bar"
+#define SECT_FRNTHEAVE				"Front Heave Spring"
+#define SECT_FRNTRGTWHEEL			"Front Right Wheel"
+#define SECT_FRNTLFTWHEEL			"Front Left Wheel"
+#define SECT_FRNTRGTSUSP			"Front Right Suspension"
+#define SECT_FRNTLFTSUSP			"Front Left Suspension"
+#define SECT_FRNTRGTBRAKE			"Front Right Brake"
+#define SECT_FRNTLFTBRAKE			"Front Left Brake"
+#define SECT_FRNTDIFFERENTIAL		"Front Differential"
+#define SECT_REAR					"Rear"
+#define SECT_REARWING				"Rear Wing"
+#define SECT_REARAXLE				"Rear Axle"
+#define SECT_REARARB				"Rear Anti-Roll Bar"
+#define SECT_REARHEAVE				"Rear Heave Spring"
+#define SECT_REARRGTWHEEL			"Rear Right Wheel"
+#define SECT_REARLFTWHEEL			"Rear Left Wheel"
+#define SECT_REARRGTSUSP			"Rear Right Suspension"
+#define SECT_REARLFTSUSP			"Rear Left Suspension"
+#define SECT_REARRGTBRAKE			"Rear Right Brake"
+#define SECT_REARLFTBRAKE			"Rear Left Brake"
+#define SECT_REARDIFFERENTIAL		"Rear Differential"
 #define SECT_CENTRALDIFFERENTIAL	"Central Differential"
-#define SECT_STEER		"Steer"
+#define SECT_STEER			"Steer"
 #define SECT_BRKSYST		"Brake System"
 #define SECT_AERODYNAMICS	"Aerodynamics"
-#define SECT_ENGINE		"Engine"
-#define SECT_CLUTCH		"Clutch"
+#define SECT_ENGINE			"Engine"
+#define SECT_CLUTCH			"Clutch"
 #define SECT_DRIVETRAIN		"Drivetrain"
 #define SECT_GEARBOX		"Gearbox"
-#define SECT_DRIVER		"Driver"
-#define SECT_BONNET		"Bonnet"
+#define SECT_DRIVER			"Driver"
+#define SECT_BONNET			"Bonnet"
 #define SECT_GROBJECTS		"Graphic Objects"
 #define SECT_EXHAUST		"Exhaust"
-#define SECT_LIGHT		"Light"
+#define SECT_LIGHT			"Light"
+#define SECT_FEATURES		"Features"
 
 /* Parameter names */
 #define PRM_CATEGORY		"category"
-#define PRM_LEN			"body length"
-#define PRM_WIDTH		"body width"
+#define PRM_LEN				"body length"
+#define PRM_WIDTH			"body width"
 #define PRM_OVERALLLEN		"overall length"
 #define PRM_OVERALLWIDTH	"overall width"
-#define PRM_HEIGHT		"body height"
-#define PRM_MASS		"mass"
+#define PRM_HEIGHT			"body height"
+#define PRM_MASS			"mass"
 #define PRM_FRWEIGHTREP		"front-rear weight repartition"
 #define PRM_FRLWEIGHTREP	"front right-left weight repartition"
 #define PRM_RRLWEIGHTREP	"rear right-left weight repartition"
 #define PRM_GCHEIGHT		"GC height"
-#define PRM_TANK		"fuel tank"
-#define PRM_FUEL		"initial fuel"
-#define PRM_CENTR		"mass repartition coefficient"
-#define PRM_INERTIA		"inertia"
+#define PRM_TANK			"fuel tank"
+#define PRM_FUEL			"initial fuel"
+#define PRM_CENTR			"mass repartition coefficient"
+#define PRM_INERTIA			"inertia"
 #define PRM_EFFICIENCY		"efficiency"
-#define PRM_TYPE		"type"
-#define PRM_SIZE		"size"
+#define PRM_TYPE			"type"
+#define PRM_SIZE			"size"
 
 /* Tires */
-#define PRM_MU			"mu"
-#define PRM_RIMDIAM		"rim diameter"
-#define PRM_TIREWIDTH		"tire width"
-#define PRM_TIREHEIGHT		"tire height"
-#define PRM_TIRERATIO		"tire height-width ratio"
-#define PRM_RIDEHEIGHT		"ride height"
-#define PRM_ROLLINGRESIST	"rolling resistance"
-#define PRM_TOE			"toe"
-#define PRM_CAMBER		"camber"
-#define PRM_CA			"stiffness"
-#define PRM_RFACTOR		"dynamic friction"
-#define PRM_EFACTOR		"elasticity factor"
-#define PRM_PRESSURE		"pressure"
-#define PRM_LOADFMAX		"load factor max"
-#define PRM_LOADFMIN		"load factor min"
-#define PRM_OPLOAD		"operating load"
+#define PRM_MU					"mu"
+#define PRM_RIMDIAM				"rim diameter"
+#define PRM_TIREWIDTH			"tire width"
+#define PRM_TIREHEIGHT			"tire height"
+#define PRM_TIRERATIO			"tire height-width ratio"
+#define PRM_RIDEHEIGHT			"ride height"
+#define PRM_ROLLINGRESIST		"rolling resistance"
+#define PRM_TOE					"toe"
+#define PRM_CAMBER				"camber"
+#define PRM_CA					"stiffness"
+#define PRM_RFACTOR				"dynamic friction"
+#define PRM_EFACTOR				"elasticity factor"
+#define PRM_PRESSURE			"pressure"
+#define PRM_LOADFMAX			"load factor max"
+#define PRM_LOADFMIN			"load factor min"
+#define PRM_OPLOAD				"operating load"
+#define PRM_OPTTEMP				"optimal temperature"
+#define PRM_INITTEMP			"initial temperature"
+#define PRM_COLDMUFACTOR		"cold mu factor"
+#define PRM_HEATINGMULT			"heating multiplier"
+#define PRM_AIRCOOLINGMULT		"air cooling multiplier"
+#define PRM_SPEEDCOOLINGMULT	"speed cooling multiplier"
+#define PRM_WEARRATE			"wear rate multiplier"
+#define PRM_FALLOFFTREADDEPTH	"falloff tread depth"
+#define PRM_FALLOFFGRIPMULT		"falloff grip multiplier"
+#define PRM_REMAININGGRIPMULT	"remaining grip multiplier"
 
-
-#define PRM_SPR			"spring"
+#define PRM_SPR				"spring"
 #define PRM_SUSPCOURSE		"suspension course"
 #define PRM_BELLCRANK		"bellcrank"
-#define PRM_PACKERS		"packers"
+#define PRM_PACKERS			"packers"
 #define PRM_SLOWBUMP		"slow bump"
 #define PRM_SLOWREBOUND		"slow rebound"
 #define PRM_FASTBUMP		"fast bump"
@@ -559,73 +617,102 @@ typedef struct CarElt
 #define PRM_BUMPLVEL		"bump limit velocity"
 #define PRM_REBOUNDLVEL		"rebound limit velocity"
 
-#define PRM_XPOS		"xpos"
-#define PRM_YPOS		"ypos"
-#define PRM_ZPOS		"zpos"
+#define PRM_XPOS			"xpos"
+#define PRM_YPOS			"ypos"
+#define PRM_ZPOS			"zpos"
 
 #define PRM_STEERLOCK		"steer lock"
 #define PRM_STEERSPD		"max steer speed"
 
-#define PRM_BRKDIAM		"disk diameter"
-#define PRM_BRKAREA		"piston area"
-#define PRM_BRKREP		"front-rear brake repartition"
+#define PRM_BRKDIAM			"disk diameter"
+#define PRM_BRKAREA			"piston area"
+#define PRM_BRKREP			"front-rear brake repartition"
 #define PRM_BRKPRESS		"max pressure"
 #define PRM_EBRKPRESS		"emergency brake pressure"
+#define PRM_BRKCOR_LR		"brake corr lr"
+#define PRM_BRKCOR_FR		"brake corr fr"
 
-#define PRM_CX			"Cx"
-#define PRM_FCL			"front Clift"
-#define PRM_RCL			"rear Clift"
+#define PRM_CX				"Cx"
+#define PRM_FCL				"front Clift"
+#define PRM_RCL				"rear Clift"
 #define PRM_FRNTAREA		"front area"
 #define PRM_WINGAREA		"area"
 #define PRM_WINGANGLE		"angle"
+#define PRM_WINGANGLEVARIABLE "variable"
+
+#define PRM_WINGTYPE		"wing type"
+#define PRM_AOAATMAX		"aoa at max"
+#define PRM_AOAATZERO		"aoa at zero"
+#define PRM_AOAOFFSET		"aoa offset"
+
+#define PRM_CLMAX			"clift max"
+#define PRM_CLATZERO		"clift at zero"
+#define PRM_CLASYMP			"clift asymptotic"
+#define PRM_DELAYDECREASE	"clift delay"
+#define PRM_CURVEDECREASE	"clift curve"
+
+#define PRM_ANGLEOFSTALL	"angle of stall"
+#define PRM_STALLWIDTH		"stall width"
+#define PRM_ASPECTRATIO		"aspect ratio"
 
 /* Engine */
-#define PRM_REVSLIM		"revs limiter"
-#define PRM_REVSMAX		"revs maxi"
+#define PRM_REVSLIM			"revs limiter"
+#define PRM_REVSMAX			"revs maxi"
 #define PRM_TICKOVER		"tickover"
-#define PRM_RPM			"rpm"
-#define PRM_TQ			"Tq"
-#define ARR_DATAPTS		"data points"
+#define PRM_RPM				"rpm"
+#define PRM_TQ				"Tq"
+#define ARR_DATAPTS			"data points"
 #define PRM_FUELCONS		"fuel cons factor"
 #define PRM_ENGBRKCOEFF		"brake coefficient"
-#define PRM_ENGBRKLINCOEFF		"brake linear coefficient"
-#define PRM_POWER		"power"
-#define PRM_TURBO         "turbo"
-#define PRM_TURBO_RPM     "turbo rpm"
-#define PRM_TURBO_FACTOR  "turbo factor"
-#define PRM_TURBO_LAG     "turbo lag"
-#define PRM_CAPACITY      "capacity"
-#define PRM_CYLINDERS     "cylinders"
-#define PRM_ENGSHAPE      "shape"
-#define PRM_ENGPOS        "position"
+#define PRM_ENGBRKLINCOEFF	"brake linear coefficient"
+#define PRM_POWER			"power"
+#define PRM_TURBO			"turbo"
+#define PRM_TURBO_RPM		"turbo rpm"
+#define PRM_TURBO_FACTOR	"turbo factor"
+#define PRM_TURBO_LAG		"turbo lag"
+#define PRM_CAPACITY		"capacity"
+#define PRM_CYLINDERS		"cylinders"
+#define PRM_ENGSHAPE		"shape"
+#define PRM_ENGPOS			"position"
 
-#define PRM_RATIO		"ratio"
-#define PRM_BIAS		"bias"
+#define PRM_RATIO			"ratio"
+#define PRM_BIAS			"bias"
 
-#define ARR_GEARS		"gears"
+#define ARR_GEARS			"gears"
 #define PRM_SHIFTTIME		"shift time"
 
 #define	PRM_ROLLCENTER		"roll center height"
 
-#define LST_RANGES		"Ranges"
+#define LST_RANGES			"Ranges"
 #define PRM_THRESHOLD		"threshold"
-#define PRM_CAR			"car"
+#define PRM_CAR				"car"
 #define PRM_WHEELSON		"wheels"
 #define PRM_TEMPLATE		"template"
-#define PRM_ENV			"env"
-#define PRM_BONNET		"bonnet"
+#define PRM_ENV				"env"
+#define PRM_BONNET			"bonnet"
 #define PRM_WHEEL_TEXTURE	"wheel texture"
 #define PRM_SHADOW_TEXTURE	"shadow texture"
 
-#define SECT_STEERWHEEL	        "Steer Wheel"
-#define PRM_SW_MODEL            "model"
-#define PRM_SW_MODELHR          "hi res model"
-#define PRM_SW_ANGLE            "angle"
-#define PRM_SW_MOVT             "movt"
+#define SECT_STEERWHEEL	    "Steer Wheel"
+#define PRM_SW_MODEL        "model"
+#define PRM_SW_MODELHR      "hi res model"
+#define PRM_SW_ANGLE        "angle"
+#define PRM_SW_MOVT         "movt"
 
-#define LST_DRIVER              "Driver"
-#define PRM_DRIVERSTEER         "steer"
-#define PRM_DRIVERMODEL         "driver"
+#define LST_DRIVER          "Driver"
+#define PRM_DRIVERSTEER     "steer"
+#define PRM_DRIVERMODEL     "driver"
+
+#define LST_REARWING        "RearWing"
+#define PRM_REARWINGANGLE   "angle"
+#define PRM_REARWINGMODEL   "rearwing"
+
+#define SECT_COCKPIT		"cockpit"
+#define PRM_MODELCOCKPIT	"model cockpit"
+
+#define SECT_WING_MODEL		"wing model"
+#define PRM_WING_1			"model 1"
+#define PRM_WING_2			"model 2"
 
 #define PRM_MIN_TQ_BIAS		"min torque bias"
 #define PRM_MAX_TQ_BIAS		"max torque bias"
@@ -723,6 +810,21 @@ typedef struct CarElt
 #define SEM_COLLISION_Z			0x08
 #define SEM_COLLISION_Z_CRASH	0x10
 
+/* features */
+#define PRM_AEROTOCG		"shifting aero coordinates"
+#define PRM_SLOWGRIP		"fixed low speed grip"
+#define PRM_REALGEARCHANGE	"realistic gear change"
+#define PRM_REVLIMIT		"realistic rev limiter"
+#define PRM_TIRETEMPDEG		"tire temperature and degradation"
+#define PRM_FIXEDWHEELFORCE	"fixed wheel force"
+#define VAL_YES			"yes"
+#define VAL_NO			"no"
+#define FEAT_AEROTOCG		0x01 //shift aero coordinates with the CG
+#define FEAT_SLOWGRIP		0x02 //fix magic formula divergence at low speeds
+#define FEAT_REALGEARCHANGE	0x04 //neutral between old and new gears without autoclutch
+#define FEAT_REVLIMIT		0x08 //rev drop when hitting the limit
+#define FEAT_TIRETEMPDEG	0x10 //tire temperature and degradation
+#define FEAT_FIXEDWHEELFORCE	0x20 //fixed wheel force in SimWheelUpdateForce
 
 #endif /* __CARV1_H__ */ 
 
