@@ -1,10 +1,10 @@
 /***************************************************************************
                  isoundengine.h -- Interface for sound engines
 
-    created              : Mon Mar 28 19:48:14 CEST 2011
-    copyright            : (C) 2011 by Jean-Philippe Meuret                         
+    created              : Mon Jul 28 19:48:14 CEST 2012
+    copyright            : (C) 2012 by Gaëtan André
     web                  : http://www.speed-dreams.org
-    version              : $Id: isoundengine.h 3741 2011-07-21 22:29:34Z pouillot $
+    version              : $Id: isoundengine.h 5095 2013-01-12 17:57:47Z pouillot $
  ***************************************************************************/
 
 /***************************************************************************
@@ -16,21 +16,20 @@
  *                                                                         *
  ***************************************************************************/
 
-/** @file   
-    	Interface for sound engines
-		Only embryonic, as long as we don't have a real separate sound engine
-		(for the moment, it is inside the graphics engine)
-    @version	$Id: isoundengine.h 3741 2011-07-21 22:29:34Z pouillot $
-*/
+ #ifndef __ISOUNDENGINE__H__
+ #define __ISOUNDENGINE__H__
 
-#ifndef __ISOUNDENGINE__H__
-#define __ISOUNDENGINE__H__
 
-class ISoundEngine
+#include "camera.h"
+
+class ISoundEngine 
 {
 public:
-
-	virtual void mute(bool bOn = true) = 0;
+ 
+    virtual void init(struct Situation* s) = 0;
+    virtual void shutdown() = 0;
+    virtual void refresh(struct Situation *s, Camera *camera) = 0;
+    virtual void mute(bool bOn = true) = 0;
 };
-
-#endif // __ISOUNDENGINE__H__
+ 
+ #endif // __ISOUNDENGINE__H__
