@@ -1,10 +1,10 @@
 /***************************************************************************
-                    tgf.h -- Interface file for The Gaming Framework                                    
+                    tgf.h -- Interface file for The Gaming Framework
                              -------------------                                         
     created              : Fri Aug 13 22:32:14 CEST 1999
-    copyright            : (C) 1999 by Eric Espie                         
-    email                : torcs@free.fr   
-    version              : $Id: tgf.h 4247 2011-12-03 18:20:28Z pouillot $                                  
+    copyright            : (C) 1999 by Eric Espie
+    email                : torcs@free.fr
+    version              : $Id: tgf.h 5349 2013-03-23 17:59:22Z pouillot $
  ***************************************************************************/
 
 /***************************************************************************
@@ -19,13 +19,16 @@
 /** @file   
     	The Gaming Framework API.
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: tgf.h 4247 2011-12-03 18:20:28Z pouillot $
+    @version	$Id: tgf.h 5349 2013-03-23 17:59:22Z pouillot $
 */
 
 #ifndef __TGF__H__
 #define __TGF__H__
 
 #include <cstdio>
+#ifdef __MINGW32__
+# include <climits>
+#endif
 
 #include "osspec.h"
 
@@ -42,6 +45,7 @@
 
 #include "modinfo.h" // Don't move this include line : needs TGF_API definition.
 
+#include <string>
 
 /** Floating point type used everywhere.
     @ingroup definitions
@@ -69,6 +73,10 @@ typedef float tdble;
 #define freez FREEZ
 
 const double PI = 3.14159265358979323846;  /**< PI */
+const double PI_2 = PI/2; /**< PI/2 =  90 deg */
+const double PI_3 = PI/3; /**< PI/3 =  60 deg */
+const double PI_4 = PI/4; /**< PI/4 =  45 deg */
+const double PI_6 = PI/6; /**< PI/6 =  30 deg */
 const tdble G = 9.80665f; /**< m/s/s */
 
 /* conversion */
@@ -171,7 +179,7 @@ typedef struct Forces
 /******************************
  * Gaming framework managment *
  ******************************/
-TGF_API void GfInit(void);
+TGF_API void GfInit(bool bWithLogging = true);
 TGF_API void GfShutdown(void);
 
 
@@ -256,6 +264,7 @@ typedef struct FList
     void		*userData;	/**< User data */
 } tFList;
 
+TGF_API bool GfDirExists(const char* pszName);
 TGF_API int GfDirCreate(const char *path);
 TGF_API tFList *GfDirGetList(const char *dir);
 TGF_API tFList *GfDirGetListFiltered(const char *dir, const char *prefix, const char *suffix);
@@ -334,10 +343,20 @@ TGF_API int GfParmSetCurStr(void *handle, const char *path, const char *key, con
 
 /* get num parameter value */
 TGF_API tdble GfParmGetNum(void *handle, const char *path, const char *key, const char *unit, tdble deflt);
+/* get min of num parameter value */
+TGF_API tdble GfParmGetNumMin(void *handle, const char *path, const char *key, const char *unit, tdble deflt);
+/* get max of num parameter value */
+TGF_API tdble GfParmGetNumMax(void *handle, const char *path, const char *key, const char *unit, tdble deflt);
 /* get num parameter value */
 TGF_API tdble GfParmGetCurNum(void *handle, const char *path, const char *key, const char *unit, tdble deflt);
+/* get min of num parameter value */
+TGF_API tdble GfParmGetCurNumMin(void *handle, const char *path, const char *key, const char *unit, tdble deflt);
+/* get max of num parameter value */
+TGF_API tdble GfParmGetCurNumMax(void *handle, const char *path, const char *key, const char *unit, tdble deflt);
 /* set num parameter value */
 TGF_API int GfParmSetNum(void *handle, const char *path, const char *key, const char *unit, tdble val);
+/* set num parameter value with min an max */
+TGF_API int GfParmSetNum(void *handle, const char *path, const char *key, const char *unit, tdble val, tdble min, tdble max);
 /* set num parameter value */
 TGF_API int GfParmSetCurNum(void *handle, const char *path, const char *key, const char *unit, tdble val);
 
@@ -417,53 +436,159 @@ TGF_API int GfParmSetCurFormulaf(void* hanlde, char const *formula, char const*
 TGF_API void GfParmShutdown (void);
 
 /********************************************************************************
- * Log/Trace Interface                                                          *
- *  - Write formated string messages at run-time to the log stream,             *
- *    with automatic prepending of current time and trace level                 *
- *    (Ex: 12:27.35.267 Debug  My formated message)                             *
- *  - GfLogFatal also exits the program after logging the message
+ * Logging / Tracing Interface                                                  *
+ *  - Multiple loggers, enabling to separate and filter traces as desired,      *
+ *  - Write formated string messages at run-time to a log stream,               *
+ *    with automatic prepending of current time, logger name and trace level    *
+ *    (Ex: 12:27:35.267 MyLogger Debug  My formated message)                    *
+ *  - GfLogFatal also exits the program after logging the message               *
  *  - Messages are given an integer "level" = "criticity",                      *
  *    (0=Fatal, 1=Error, 2=Warning, 3=Info, 4=Trace, 5=Debug, ...)              *
- *  - Messages are actually logged into the stream only if their level          *
+ *  - Messages are actually logged into the traget stream only if their level   *
  *    is lower than the current threshold,                                      *
- *  - Default stream is stderr, but it can be changed at run-time to any FILE*, *
+ *  - Default stream is stderr, but it can be changed at startup or at run-time *
+ *    to any FILE*, or any file from its path-name                              *
  *  - Default level threshold is #defined at compile time through TRACE_LEVEL,  *
- *    but it can be changed at run-time to any other level.                     *
+ *    but it can be changed at startup or at run-time to any other level.       *
+ *  - Each logger can be configured at startup through an XML file :            *
+ *    <user settings>/config/logging.xml (see source in data/config)            *
  ********************************************************************************/
 
-TGF_API void GfLogFatal(const char *pszFmt, ...);
+//****************************************
+// Logger class
+
+class TGF_API GfLogger
+{
+ public:
+
+	//! Trace level / criticity : enum or integer if > eDebug.
+	enum { eFatal = 0, eError, eWarning, eInfo, eTrace, eDebug };
+
+	//! Destructor.
+	virtual ~GfLogger();
+
+	//! Name.
+	const std::string& name() const;
+
+	//! Criticity level threshold (ascending level means descending criticity).
+	int levelThreshold() const;
+	void setLevelThreshold(int nLevel);
+
+	//! Output lines header columns selection (order not customisable, only there or not).
+	enum { eNone=0, eTime=0x01, eLogger=0x02, eLevel=0x04, eAll=eTime|eLogger|eLevel };
+	unsigned headerColumns() const;
+	void setHeaderColumns(unsigned bfHdrCols);
+
+	//! Output stream.
+	FILE* stream() const;
+	void setStream(FILE* pFile, bool bLogFileChange=true);
+	void setStream(const std::string& strPathname); // "stdout" or "stderr" also supported.
+	
+	//! Tracing functions (name gives the trace level / criticity).
+	void fatal(const char *pszFmt, ...); // Warning : This one calls exit(1) at the end !
+#ifdef TRACE_OUT
+	void error(const char *pszFmt, ...);
+	void warning(const char *pszFmt, ...);
+	void info(const char *pszFmt, ...);
+	void trace(const char *pszFmt, ...);
+	void debug(const char *pszFmt, ...);
+#else // TRACE_OUT
+	// The compiler should simply skip calls to these ...
+	inline void error(const char *pszFmt, ...) {};
+	inline void warning(const char *pszFmt, ...) {};
+	inline void info(const char *pszFmt, ...) {};
+	inline void trace(const char *pszFmt, ...) {};
+	inline void debug(const char *pszFmt, ...) {};
+#endif // TRACE_OUT
+
+	//! Generic tracing function (you must specify the level, enum or integer if > eDebug).
+#ifdef TRACE_OUT
+	void message(int nLevel, const char *pszFmt, ...);
+#else // TRACE_OUT
+	// The compiler should simply skip calls to this ...
+	inline void message(int nLevel, const char *pszFmt, ...) {};
+#endif // TRACE_OUT
+
+	//! Instance getter (you can't readily instanciate loggers).
+	static GfLogger* instance(const std::string& name);
+	
+	//! Boot the logging system (only 1 logger set up : GfLogDefault, and with default settings).
+	static void boot(bool bWithLogging = true);
+	
+	//! Complete logging system initialisation (create and / or configure all loggers from XML settings).
+	static void setup();
+	
+ protected:
+
+	//! Constructors (protected in order to forbid direct instanciation).
+	GfLogger(); // Forced default constructor, to prevent the compiler to make it public.
+	GfLogger(const std::string& strName, FILE* pFile = stderr,
+			 int nLvlThresh = TRACE_LEVEL, unsigned bfHdrCols = GfLogger::eAll);
+	GfLogger(const std::string& strName, const std::string& strFilename,
+			 int nLvlThresh = TRACE_LEVEL, unsigned bfHdrCols = GfLogger::eAll);
+
+	// Output a line header with required columns, if not level-filtered out.
+	void putLineHeader(int nLevel);
+
+ protected:
+
+	//! The logger name / id.
+	std::string _strName;
+	
+	//! The header columns to output in the target stream.
+	unsigned _bfHdrCols;
+
+	//! The target output stream.
+	FILE* _pStream;
+
+	//! The trace level threshold (less critical traces are not logged).
+	int _nLvlThresh;
+	
+	//! Flag indicating if the last logged line ended with a new-line.
+	bool _bNeedsHeader;
+	
+	//! Flag indicating if output is enabled (for all loggers).
+	static bool _bOutputEnabled;
+};
+
+// The logging system run-time settings file (in GfLocalDir()).
+#define LOGGING_CFG "config/logging.xml"
+
+// The default logger : NEVER use it before GfInit has been called !
+// Note: This implementation through the GfPLogDefault variable initialised in GfLogger::boot()
+//       is more efficient than the following one, through a simple macro :
+//       #define GfLogDefault (*GfLogger::instance("Default"))
+TGF_API extern GfLogger* GfPLogDefault;
+#define GfLogDefault (*GfPLogDefault)
+
+// Backward compatibility (for before GfLogger appeared, as long as not used readily everywhere).
+#define GfLogFatal GfLogDefault.fatal
 
 #ifdef TRACE_OUT
 
-TGF_API void GfLogError(const char *pszFmt, ...);
-TGF_API void GfLogWarning(const char *pszFmt, ...);
-TGF_API void GfLogInfo(const char *pszFmt, ...);
-TGF_API void GfLogTrace(const char *pszFmt, ...);
-TGF_API void GfLogDebug(const char *pszFmt, ...);
-
-TGF_API void GfLogMessage(int nLevel, const char *pszFmt, ...);
-TGF_API void GfLogSetFile(const char* pszFileName);
-TGF_API void GfLogSetStream(FILE* fStream);
-TGF_API void GfLogSetLevelThreshold(int nLevel);
+#define GfLogError GfLogDefault.error
+#define GfLogWarning GfLogDefault.warning
+#define GfLogInfo GfLogDefault.info
+#define GfLogTrace GfLogDefault.trace
+#define GfLogDebug GfLogDefault.debug
+#define GfLogMessage GfLogDefault.message
+#define GfLogSetStream GfLogDefault.setStream
+#define GfLogSetLevelThreshold GfLogDefault.setLevelThreshold
 
 #else // TRACE_OUT
 
-static inline void GfLogNothing(const char *pszFmt, ...) {};
-
-#define GfLogError GfLogNothing
-#define GfLogWarning GfLogNothing
-#define GfLogInfo GfLogNothing
-#define GfLogTrace GfLogNothing
-#define GfLogDebug GfLogNothing
-
-static inline void GfLogMessage(int nLevel, const char *pszFmt, ...) {};
-#define GfLogSetFile(pszFileName)
-#define GfLogSetStream(fStream)
-#define GfLogSetLevelThreshold(nLevel)
+#define GfLogError
+#define GfLogWarning
+#define GfLogInfo
+#define GfLogTrace
+#define GfLogDebug
+#define GfLogMessage
+#define GfLogSetStream
+#define GfLogSetLevelThreshold
 
 #endif // TRACE_OUT
 
-// Backward compatibility.
+// Backward compatibility for old TORCS inherited code (like robots).
 #define GfFatal GfLogFatal
 #define GfError GfLogError
 #define GfOut   GfLogInfo
@@ -487,8 +612,8 @@ TGF_API int GfNearestPow2(int x);
 
 typedef struct 
 {
-    int		curNum;
-    tdble	val[GF_MEAN_MAX_VAL+1];
+	int		curNum;
+	tdble	val[GF_MEAN_MAX_VAL+1];
 } tMeanVal;
 
 TGF_API tdble gfMean(tdble v, tMeanVal *pvt, int n, int w);
@@ -505,6 +630,7 @@ TGF_API bool GfSetThreadAffinity(int nCPUId);
 
 TGF_API void GfSleep(double seconds);
 
+TGF_API bool GfGetOSInfo(std::string& strName, int& nMajor, int& nMinor, int& nPatch, int& nBits);
 
 /***************************
  * Run-time dirs accessors *
