@@ -4,7 +4,7 @@
     created              : Fri Aug 13 22:32:14 CEST 1999
     copyright            : (C) 1999 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: tgfclient.h 4628 2012-03-31 09:14:21Z pouillot $
+    version              : $Id: tgfclient.h 5163 2013-02-19 18:28:35Z pouillot $
 ***************************************************************************/
 
 /***************************************************************************
@@ -19,7 +19,7 @@
 /** @file   
         The Gaming Framework API (client part).
     @author     <a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version    $Id: tgfclient.h 4628 2012-03-31 09:14:21Z pouillot $
+    @version    $Id: tgfclient.h 5163 2013-02-19 18:28:35Z pouillot $
 */
 
 #ifndef __TGFCLIENT__H__
@@ -42,7 +42,15 @@
 #else
 #  include <plib/js.h>
 #endif
-#include <SDL/SDL_keysym.h>
+
+#include <SDL.h>
+#if 0
+#if SDL_MAJOR_VERSION >= 2
+#include <SDL_keyboard.h>
+#else
+#include <SDL_keysym.h>
+#endif
+#endif
 
 #include <tgf.hpp>
 
@@ -285,6 +293,7 @@ TGFCLIENT_API void GfuiHelpScreen(void *targetScreen);
 TGFCLIENT_API void GfuiHelpScreen(void *targetScreen, void *returnScreen);
 TGFCLIENT_API void GfuiScreenShot(void *notused);
 TGFCLIENT_API void GfuiScreenAddBgImg(void *scr, const char *filename);
+TGFCLIENT_API void GfuiScreenAddMusic(void *scr, const char *filename);
 TGFCLIENT_API void GfuiKeyEventRegister(void *scr, tfuiKeyCallback onKeyAction);
 TGFCLIENT_API void GfuiKeyEventRegisterCurrent(tfuiKeyCallback onKeyAction);
 TGFCLIENT_API void GfuiInitWindowPositionAndSize(int x, int y, int w, int h);
@@ -748,12 +757,14 @@ class TGFCLIENT_API GfuiApplication : public GfApplication
  public:
 
 	//! Constructor.
-	GfuiApplication(const char* pszName, const char* pszVersion, const char* pszDesc,
-					int argc = 0, char** argv = 0);
+    GfuiApplication(const char* pszName, const char* pszVersion, const char* pszDesc);
 
 	//! Destructor.
 	virtual ~GfuiApplication();
 	
+	//! Initialization.
+    virtual void initialize(bool bLoggingEnabled, int argc = 0, char **argv = 0);
+
 	//! Parse the command line options (updates _lstOptionsLeft).
 	bool parseOptions();
 
@@ -774,7 +785,7 @@ class TGFCLIENT_API GfuiApplication : public GfApplication
 
 
 //! Shortcut to the application singleton.
-inline TGFCLIENT_API GfuiApplication& GfuiApp()
+inline GfuiApplication& GfuiApp()
 {
 	return dynamic_cast<GfuiApplication&>(GfApplication::self());
 }
