@@ -4,7 +4,7 @@
     created              : Sun Jan 30 23:00:06 CET 2000
     copyright            : (C) 2000 by Eric Espie
     email                : torcs@free.fr
-    version              : $Id: track.h 3761 2011-07-29 22:24:35Z kmetykog $
+    version              : $Id: track.h 4902 2012-08-27 10:04:20Z kmetykog $
 
  ***************************************************************************/
 
@@ -20,7 +20,7 @@
 /** @file
     		This is the track structure.
     @author	<a href=mailto:torcs@free.fr>Eric Espie</a>
-    @version	$Id: track.h 3761 2011-07-29 22:24:35Z kmetykog $
+    @version	$Id: track.h 4902 2012-08-27 10:04:20Z kmetykog $
     @ingroup	trackstruct
 */
 
@@ -49,6 +49,8 @@
 
 #define TRK_SECT_LOCAL	"Local Info"
 
+#define TRK_ATT_STATION "station"
+#define TRK_ATT_TIMEZONE "timezone"
 #define TRK_ATT_ANYRAINLKHD "overall rain likelyhood"
 #define TRK_ATT_LITTLERAINLKHD "little rain likelyhood"
 #define TRK_ATT_MEDIUMRAINLKHD "medium rain likelyhood"
@@ -581,12 +583,15 @@ typedef struct TrackGraphicInfo
 typedef struct TrackLocalInfo
 {
 	/* Constant spec. data, read from <track>.xml */
+	const char *station;	/**<Station Weather */
+	int	timezone; /**< timezone for real timeday with not connection http */
     tdble anyrainlkhood; /**< Overall likelyhood of having rain (when random) [0, 1] */
     tdble littlerainlkhood; /**< Likelyhood of having little rain when it rains [0, 1] */
     tdble mediumrainlkhood;	 /**< Likelyhood of having medium rain when it rains [0, 1-little] */
 
 	/* Actual data for a race (computed at race start) */
     tdble timeofday;   /**< Local time of day, in seconds from 0:00 (0 = 0:00, 86400 = 24:00 */
+    int timeofdayindex;
 	tdble sunascension; /**< Local sun "height" (related to the latitude, not to the time of day) */
 
     int clouds;	/**< Clouds coverage in the sky  (warning : consistency with RM_VAL_CLOUDS_*) */
